@@ -285,7 +285,7 @@ wnck_selector_make_menu_consistent (WnckSelector *selector)
           separator_is_last = TRUE;
           separator = GTK_WIDGET (l->data);
         }
-      else if (GTK_WIDGET_VISIBLE (l->data) &&
+      else if (gtk_widget_get_visible (l->data) &&
                l->data != selector->priv->no_windows_item)
         {
           separator_is_last = FALSE;
@@ -447,7 +447,7 @@ wnck_selector_window_workspace_changed (WnckWindow   *window,
 
   item = NULL;
 
-  if (!selector->priv->menu || !GTK_WIDGET_VISIBLE (selector->priv->menu))
+  if (!selector->priv->menu || !gtk_widget_get_visible (selector->priv->menu))
     return;
 
   if (!selector->priv->window_hash)
@@ -583,6 +583,7 @@ wnck_selector_item_new (WnckSelector *selector,
   };
 
   item = gtk_image_menu_item_new ();
+  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
 
   ellipsizing_label = gtk_label_new (label);
   gtk_misc_set_alignment (GTK_MISC (ellipsizing_label), 0.0, 0.5);
@@ -820,7 +821,7 @@ wnck_selector_window_opened (WnckScreen *screen,
 {
   wnck_selector_connect_to_window (selector, window);
 
-  if (!selector->priv->menu || !GTK_WIDGET_VISIBLE (selector->priv->menu))
+  if (!selector->priv->menu || !gtk_widget_get_visible (selector->priv->menu))
     return;
 
   if (!selector->priv->window_hash)
@@ -841,7 +842,7 @@ wnck_selector_window_closed (WnckScreen *screen,
   if (window == selector->priv->icon_window)
     wnck_selector_set_active_window (selector, NULL);
 
-  if (!selector->priv->menu || !GTK_WIDGET_VISIBLE (selector->priv->menu))
+  if (!selector->priv->menu || !gtk_widget_get_visible (selector->priv->menu))
     return;
 
   if (!selector->priv->window_hash)
@@ -864,7 +865,7 @@ wnck_selector_workspace_created (WnckScreen    *screen,
                                  WnckWorkspace *workspace,
                                  WnckSelector  *selector)
 {
-  if (!selector->priv->menu || !GTK_WIDGET_VISIBLE (selector->priv->menu))
+  if (!selector->priv->menu || !gtk_widget_get_visible (selector->priv->menu))
     return;
 
   /* this is assuming that the new workspace will have a higher number
@@ -887,7 +888,7 @@ wnck_selector_workspace_destroyed (WnckScreen    *screen,
   GtkWidget *destroy;
   int        i;
 
-  if (!selector->priv->menu || !GTK_WIDGET_VISIBLE (selector->priv->menu))
+  if (!selector->priv->menu || !gtk_widget_get_visible (selector->priv->menu))
     return;
 
   destroy = NULL;
